@@ -1,5 +1,5 @@
 /* -*- C++ -*-
- * Copyright 2019-2024 LibRaw LLC (info@libraw.org)
+ * Copyright 2019-2025 LibRaw LLC (info@libraw.org)
  *
 
  LibRaw is free software; you can redistribute it and/or modify
@@ -40,6 +40,9 @@ void LibRaw::GetNormalizedModel()
       { CanonID_EOS_M5,            "EOS M5"},
       { CanonID_EOS_M100,          "EOS M100"},
       { CanonID_EOS_M6,            "EOS M6"},
+
+      { CanonID_EOS_R5_C,          "EOS R5 C"},
+
       { CanonID_EOS_1D,            "EOS-1D"},
       { CanonID_EOS_1Ds,           "EOS-1Ds"},
       { CanonID_EOS_10D,           "EOS 10D"},
@@ -107,6 +110,8 @@ void LibRaw::GetNormalizedModel()
       { CanonID_EOS_R50,           "EOS R50"},
       { CanonID_EOS_R6m2,          "EOS R6 Mark II"},
       { CanonID_EOS_R8,            "EOS R8"},
+      { CanonID_EOS_R1,            "EOS R1"},
+      { CanonID_EOS_R5_Mark_II,    "EOS R5 Mark II"}, // EOS R5m2
       { CanonID_EOS_R100,          "EOS R100"}
     },
 #if 0
@@ -135,6 +140,7 @@ void LibRaw::GetNormalizedModel()
       { OlyID_TG_4,            "TG-4"},
       { OlyID_TG_5,            "TG-5"},
       { OlyID_TG_6,            "TG-6"},
+      { OlyID_TG_7,            "TG-7"},
       { OlyID_E_10,            "E-10"},
       { OlyID_AIR_A01,         "AIR A01"},
       { OlyID_AIR_A01,         "AIR-A01"},
@@ -275,10 +281,12 @@ void LibRaw::GetNormalizedModel()
       { PentaxID_K_3_II,       "K-3 II"},       // Ricoh
       { PentaxID_GR_III,       "GR III"},       // Ricoh
       { PentaxID_K_70,         "K-70"},         // Ricoh
+      { PentaxID_KF,           "KF"},           // Ricoh
       { PentaxID_KP,           "KP"},           // Ricoh
       { PentaxID_K_1_Mark_II,  "K-1 Mark II"},  // Ricoh
       { PentaxID_K_3_III,      "K-3 Mark III"}, // Ricoh
       { PentaxID_GR_IIIx,      "GR IIIx"},
+      { PentaxID_K_3_III_Mono, "K-3 Mark III Monochrome"},
     },
 #endif
     sonique[] = {
@@ -341,7 +349,7 @@ void LibRaw::GetNormalizedModel()
       { SonyID_DSC_RX100M4,    "DSC-RX100M4"},
       { SonyID_DSC_RX10M2,     "DSC-RX10M2"},
       { SonyID_DSC_RX1RM2,     "DSC-RX1RM2"},
-      { SonyID_ILCE_QX1,       "ILCE-QX1"},
+      { SonyID_ILCE_QX1,       "ILCE-QX1"},     // Sony UMC-R10C
       { SonyID_ILCE_7RM2,      "ILCE-7RM2"},
       { SonyID_ILCE_7SM2,      "ILCE-7SM2"},
       { SonyID_ILCA_68,        "ILCA-68"},
@@ -381,11 +389,14 @@ void LibRaw::GetNormalizedModel()
 
       { SonyID_ILCE_7RM5,      "ILCE-7RM5"},
       { SonyID_ILME_FX30,      "ILME-FX30"},
+      { SonyID_ILCE_9M3,       "ILCE-9M3"},
       { SonyID_ZV_E1,          "ZV-E1"},
       { SonyID_ILCE_6700,      "ILCE-6700"},
       { SonyID_ZV_1M2,         "ZV-1M2"},
       { SonyID_ILCE_7CR,       "ILCE-7CR"},
       { SonyID_ILCE_7CM2,      "ILCE-7CM2"},
+      { SonyID_ILX_LR1,        "ILX-LR1"},
+      { SonyID_ZV_E10M2,       "ZV-E10M2"},
     };
 
   static const char *orig;
@@ -406,6 +417,7 @@ void LibRaw::GetNormalizedModel()
     "@S200EXR", "S205EXR",
     "@X-T1 IR", "X-T1IR",
     "@GFX 100 II", "GFX100 II",
+    "@GFX 100S II", "GFX100S II",
     "@GFX 100S", "GFX100S",
     "@GFX 50S II", "GFX50S II"
   };
@@ -496,6 +508,7 @@ void LibRaw::GetNormalizedModel()
     "@E-M1 Mark III", "E-M1MarkIII", "E-M1_M3",
     "@E-M5 Mark II", "E-M5MarkII", "E-M5_M2",
     "@E-M5 Mark III", "E-M5MarkIII", "E-M5_M3",
+    "@OM-1 Mark II", "OM-1MarkII", "OM-1_M2",
     "@SH-2", "SH-3",
     "@SP-310", "SP310",
     "@SP-320", "SP320",
@@ -1492,9 +1505,9 @@ void LibRaw::SetStandardIlluminants (unsigned makerIdx, const char* /*normModel*
     if (makerIdx == LIBRAW_CAMERAMAKER_Olympus ) {
 		for (int i = 0; i < 64 && icWBCCTC[i][0]; i++) {
         if (icWBCCTC[i][0] == 3000)
-          FORC4 icWBC[LIBRAW_WBI_Ill_A][c] = icWBCCTC[i][c+1];
+          FORC4 icWBC[LIBRAW_WBI_Ill_A][c] = int(icWBCCTC[i][c+1]);
         else if (icWBCCTC[i][0] == 6600)
-          FORC4 icWBC[LIBRAW_WBI_D65][c] = icWBCCTC[i][c+1];
+          FORC4 icWBC[LIBRAW_WBI_D65][c] = int(icWBCCTC[i][c+1]);
       }
     }
   }
